==> apache-iotdb-1.2.2-source-release.zip: apache-iotdb-1.2.2/iotdb-core/node-commons/src/main/java/org/apache/iotdb/commons/schema/view/viewExpression/leaf/TimeSeriesViewOperand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.commons.schema.view.viewExpression.leaf;

import org.apache.iotdb.commons.schema.view.viewExpression.ViewExpressionType;
import org.apache.iotdb.commons.schema.view.viewExpression.visitor.ViewExpressionVisitor;
import org.apache.iotdb.tsfile.utils.ReadWriteIOUtils;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.Objects;

public class TimeSeriesViewOperand extends LeafViewOperand {

  // region member variables and init functions
  private String pathString;

  public TimeSeriesViewOperand(String path) {
    this.pathString = path;
  }

  public TimeSeriesViewOperand(ByteBuffer byteBuffer) {
    this.pathString = ReadWriteIOUtils.readString(byteBuffer);
  }

  public TimeSeriesViewOperand(InputStream inputStream) {
    try {
      this.pathString = ReadWriteIOUtils.readString(inputStream);
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }
  // endregion

  // region common interfaces that have to be implemented
  @Override
  public <R, C> R accept(ViewExpressionVisitor<R, C> visitor, C context) {
    return visitor.visitTimeSeriesOperand(this, context);
  }

  @Override
  public ViewExpressionType getExpressionType() {
    return ViewExpressionType.TIMESERIES;
  }

  @Override
  public String toString(boolean isRoot) {
    return this.pathString;
  }

  @Override
  protected void serialize(ByteBuffer byteBuffer) {
    ReadWriteIOUtils.write(pathString, byteBuffer);
  }

  @Override
  protected void serialize(OutputStream stream) throws IOException {
    ReadWriteIOUtils.write(pathString, stream);
  }
  // endregion

  public String getPathString() {
    return pathString;
  }

  public void setPathString(String path) {
    this.pathString = path;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TimeSeriesViewOperand that = (TimeSeriesViewOperand) o;
    return Objects.equals(pathString, that.pathString);
  }

  @Override
  public int hashCode() {
    return Objects.hash(pathString);
  }
}

==> apache-iotdb-1.3.5-source-release.zip: apache-iotdb-1.3.5/iotdb-core/node-commons/src/main/java/org/apache/iotdb/commons/schema/view/viewExpression/leaf/TimeSeriesViewOperand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.commons.schema.view.viewExpression.leaf;

import org.apache.iotdb.commons.schema.view.viewExpression.ViewExpressionType;
import org.apache.iotdb.commons.schema.view.viewExpression.visitor.ViewExpressionVisitor;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.Objects;

public class TimeSeriesViewOperand extends LeafViewOperand {

  // region member variables and init functions
  private String pathString;

  public TimeSeriesViewOperand(String path) {
    this.pathString = path;
  }

  public TimeSeriesViewOperand(ByteBuffer byteBuffer) {
    this.pathString = ReadWriteIOUtils.readString(byteBuffer);
  }

  public TimeSeriesViewOperand(InputStream inputStream) {
    try {
      this.pathString = ReadWriteIOUtils.readString(inputStream);
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  // endregion

  // region common interfaces that have to be implemented
  @Override
  public <R, C> R accept(ViewExpressionVisitor<R, C> visitor, C context) {
    return visitor.visitTimeSeriesOperand(this, context);
  }

  @Override
  public ViewExpressionType getExpressionType() {
    return ViewExpressionType.TIMESERIES;
  }

  @Override
  public String toString(boolean isRoot) {
    return this.pathString;
  }

  @Override
  protected void serialize(ByteBuffer byteBuffer) {
    ReadWriteIOUtils.write(pathString, byteBuffer);
  }

  @Override
  protected void serialize(OutputStream stream) throws IOException {
    ReadWriteIOUtils.write(pathString, stream);
  }

  // endregion

  public String getPathString() {
    return pathString;
  }

  public void setPathString(String path) {
    this.pathString = path;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TimeSeriesViewOperand that = (TimeSeriesViewOperand) o;
    return Objects.equals(pathString, that.pathString);
  }

  @Override
  public int hashCode() {
    return Objects.hash(pathString);
  }
}
